Skip to contents

Variable importance function for Rforce object

Usage

# S3 method for class 'Rforce'
vimp(forest)

Arguments

forest

An Rforce object

Value

A matrix containing variable importance statistics for each variable in each tree of the forest, row correspond to trees and columns correspond to variables.