Calculate the WRSS
Arguments
- df_test
a data frame contains composite event observations
- weights_by_status
a vector, the weights assign to each event type
- lambda_pred
a matrix contains the predicated hazard rate for each subject at each interval
- length_cpius
a vector, the length of each CPIU
- time_point
a scalar, the time point to evaluate WRSS